plots: Plot Method for GPArotation Objects

plot.GPArotationR Documentation

Plot Method for GPArotation Objects

Description

Produces visual summaries of rotated factor matrices, including an APA-style salient table-style, a heatmap, a tripartite pairs plot of factor geometry, a macro-level profile bar chart, a target rotation schema, a rotation trajectory view, or a set of diagnostics.

Usage

  ## S3 method for class 'GPArotation'
plot(x, type = c("salient", "pairs", "profile", "vector", 
     "target", "heatmap", "trajectory", "diagnostics", "residuals"), 
     hide_hyperplane = FALSE, salient = 0.40, cutoff = .1, R = NULL, 
     factors = c(1,2), items = NULL, main = NULL, ...)
     
  

Arguments

x

An object of class "GPArotation".

type

A character string indicating the type of plot. Must be one of "salient", "pairs", or "profile", "vector", "target", "heatmap", "trajectory", "diagnostics", residuals.

hide_hyperplane

Boolean. Hide values below cutoff. Default is FALSE.

salient

Numeric. Absolute values equal to or above this are highlighted as salient. Default is 0.40.

cutoff

Numeric. Absolute values strictly below this are considered noise/hyperplane. Default is 0.1.

R

Correlation matrix. If not provided taken from GPArotation object. Default is NULL.

factors

Two factors used in trajectory plot. Default = c(1,2).

items

items plotted in the trajectory plot. All items are plotted by default. Default = NULL.

main

main title where applicable. Default = NULL.

...

Additional graphical parameters passed to base plotting functions.

Value

Invisibly returns the original x object.

Author(s)

Your Name

Examples

  ## Not run: 
    # Assuming 'res' is a fitted GPArotation object:
    plot(res, type = "salient")
    plot(res, type = "pairs")
    plot(res, type = "profile")
  
## End(Not run)

GPArotation documentation built on June 18, 2026, 9:06 a.m.