| Harman | R Documentation |
Unrotated factor loading matrix extracted by the centroid method for Harman's 8 physical variables, a classic dataset in factor analysis.
data(Harman)
Harman8: a 8 \times 2 numeric matrix of
unrotated centroid factor loadings. Row names are variable
names; column names are CF1 and CF2.
Harman8 is a 8 \times 2 matrix of unrotated
factor loadings extracted by the centroid method (Table 14.3 in
Harman, 1976) from the correlation matrix of 8 physical measurements
taken on 305 girls (Table 2.3 in Harman, 1976). The centroid method
was a standard extraction procedure before iterative methods became
computationally feasible. The two columns represent unrotated centroid
factors (CF1 and CF2). Row names are the 8 variable
names.
The covariance matrix for these 8 physical variables is available
in base R (see Harman23.cor).
Harman, H.H. (1976). Modern Factor Analysis (3rd ed.). University of Chicago Press.
Harman23.cor,
GPForth,
rotations,
Thurstone,
WansbeekMeijer,
CCAI
data(Harman, package = "GPArotation")
# Centroid unrotated loadings from Harman (1976) Table 14.3
print(Harman8)
# Rotate the centroid solution
quartimax(Harman8)
oblimin(Harman8, randomStarts = 100)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.