View source: R/NormalizingWeight.R
| NormalizingWeight | R Documentation |
Internal utility function that computes normalizing weights for factor
loading matrices prior to rotation. Called by GPForth,
GPFoblq, and the random-start wrappers.
NormalizingWeight(A, normalize=FALSE)
normalize |
controls normalization. One of:
|
NormalizingWeight is not exported from the NAMESPACE and is
called internally by GPForth, GPFoblq, and the
random-start wrapper functions. For a full description of the
normalize argument and its options, see GPFRSorth.
The choice of normalization method can affect the rotation solution and its interpretation. For a detailed investigation of the effects of normalization on factor rotations, see Nguyen and Waller (2023).
A numeric vector of normalizing weights. This function is not exported
from the NAMESPACE and is only called internally by the gradient projection
rotation functions. See GPFRSorth for details on the
normalize argument.
Cureton, E.E. and Mulaik, S.A. (1975). The weighted varimax rotation and the promax rotation. Psychometrika, 40(2), 183–195. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1007/BF02291565")}
Nguyen, H.V. and Waller, N.G. (2023). Local minima and factor rotations in exploratory factor analysis. Psychological Methods, 28(5), 1122–1141. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1037/met0000467")}
GPFRSorth,
GPForth
data("CCAI", package = "GPArotation")
# Kaiser normalization
factanal(factors = 3, covmat = CCAI_R, n.obs = 461, rotation = "oblimin",
control = list(rotate = list(normalize = TRUE)))
data(Harman, package = "GPArotation")
# two ways to do Kaiser normalization
quartimin(Harman8, normalize = TRUE, randomStarts = 100)
quartimin(Harman8, normalize = "Kaiser", randomStarts = 100)
# Cureton-Mulaik normalization
quartimin(Harman8, normalize = "CM", randomStarts = 100)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.