| WansbeekMeijer | R Documentation |
Correlation matrix for Netherlands television viewership, used as an example dataset for factor rotation. From Wansbeek and Meijer (2000), page 171.
data(WansbeekMeijer)
NetherlandsTV is a list with components:
$cov: a 7 \times 7 numeric correlation matrix
$n.obs: sample size (2154)
NetherlandsTV is a list with components $cov
(a 7 \times 7 correlation matrix for 7 television
viewership variables measured in the Netherlands) and $n.obs
(sample size, 2154). Use cov2cor(NetherlandsTV\$cov) to obtain
the correlation matrix, or pass NetherlandsTV directly to
factanal which handles the list structure
automatically. It is used throughout the GPArotation
documentation and vignettes as an example dataset for oblique rotation
with 2 or 3 factors.
Wansbeek, T. and Meijer, E. (2000). Measurement Error and Latent Variables in Econometrics. North-Holland.
GPForth,
rotations,
Thurstone,
Harman,
CCAI
data(WansbeekMeijer, package = "GPArotation")
# Correlation matrix
round(cov2cor(NetherlandsTV$cov), 2)
# factanal picks up n.obs automatically from the list
factanal(factors = 2, covmat = NetherlandsTV, rotation = "none")
# Two-step oblique rotation
fa.unrotated <- factanal(factors = 3, covmat = NetherlandsTV,
rotation = "none")
oblimin(loadings(fa.unrotated), randomStarts = 100)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.