The loading matrix is rotated so that the \(k\) rows indicated by
reference form the Cholesky factorization given by
t(chol(L[reference,] %*% t(L[reference,]))).
This defines the rotation transformation, which is then applied to all
rows to give the rotated loading matrix.
The optimization is not iterative and does not use the gradient projection
algorithm. The function can be used directly or passed to factor analysis
functions like factanal via the rotation
argument.
This parameterization has several useful properties:
It can be useful for comparison with published results in this
parameterization.
Standard errors are more straightforward to compute because the
solution corresponds to an unconstrained optimization.
Models with \(k\) and \(k+1\) factors are nested,
making it straightforward to test the \(k\)-factor model
versus the \((k+1)\)-factor model. In particular, the
Wald test and LM test can be used in addition to the LR test.
The test of a \(k\)-factor model versus a
\((k+1)\)-factor model is a joint test of whether all
free parameters (loadings) in the \((k+1)\)st column
are zero.
For some purposes, only the subspace spanned by the factors
matters, not the specific parameterization within this subspace.
Back-predicted indicators (the explained portion of the
indicators) do not depend on the rotation method. Combined with
the greater ease of obtaining correct standard errors, this
allows easier and more accurate prediction standard errors.
This parameterization and its standard errors can be used to
detect identification problems (McDonald, 1999, pp. 181--182).
One use of echelon rotation is obtaining good starting values for
subsequent rotation, though it may seem counterintuitive to rotate
towards this solution afterwards.