The loading matrix is rotated so that the \(k\) rows indicated by
identity form an identity matrix, with the remaining
\(M-k\) rows as free parameters. \(\Phi\) is also free.
The optimization is not iterative and does not use the gradient projection
algorithm. The function can be used directly or passed to factor analysis
functions like factanal via the rotation
argument.
Viewed as a rotation method it is oblique, with an explicit solution.
Given an initial loadings matrix \(L\) partitioned as
\(L = (L_1^T, L_2^T)^T\), the rotated loadings
matrix is \((I, (L_2 L_1^{-1})^T)^T\)
and \(\Phi = L_1 L_1^T\), where \(I\) is
the \(k \times k\) identity matrix. It is assumed that
\(\Phi = I\) for the initial loadings matrix.
Not all authors consider this representation to be a rotation in the
strict sense.
This parameterization has several useful properties:
It can be useful for comparison with published results in this
parameterization.
Standard errors are more straightforward to compute because the
solution corresponds to an unconstrained optimization.
One may have prior knowledge about which reference variables load
on only one factor without imposing restrictive constraints on
other loadings --- in this sense it has similarities to CFA.
For some purposes, only the subspace spanned by the factors
matters, not the specific parameterization within this subspace.
Back-predicted indicators (the explained portion of the
indicators) do not depend on the rotation method. Combined with
the greater ease of obtaining correct standard errors, this
allows easier and more accurate prediction standard errors.
One use of this parameterization is obtaining good starting values for
subsequent rotation, though it may seem counterintuitive to rotate
towards this solution afterwards.
Note that the rotated loadings for non-identity rows may be large in
magnitude and should not be interpreted as standard factor loadings.
\(\Phi\) is the factor covariance matrix
\(L_1 L_1^T\) and is not a correlation matrix —
diagonal values are not constrained to 1.