| vgQ | R Documentation |
Rotation criterion functions that compute the value and gradient of the rotation objective Q. Not exported from the package NAMESPACE.
vgQ.oblimin(L, gam=0)
vgQ.quartimin(L)
vgQ.target(L, Target=NULL)
vgQ.pst(L, W=NULL, Target=NULL)
vgQ.oblimax(L)
vgQ.entropy(L)
vgQ.quartimax(L)
vgQ.varimax(L)
vgQ.simplimax(L, k=nrow(L))
vgQ.bentler(L)
vgQ.tandemI(L)
vgQ.tandemII(L)
vgQ.geomin(L, delta=0.01)
vgQ.bigeomin(L, delta=0.01)
vgQ.cf(L, kappa=0)
vgQ.infomax(L)
vgQ.mccammon(L)
vgQ.varimin(L)
vgQ.bifactor(L)
vgQ.lp.wls(L, W)
L |
a factor loading matrix. |
gam |
0 = Quartimin, 0.5 = Biquartimin, 1 = Covarimin. |
Target |
rotation target matrix for objective calculation. |
W |
weight matrix; weighting of each element in target rotation
( |
k |
number of near-zero loadings to target. |
delta |
small constant added to |
kappa |
complexity weight for the Crawford-Ferguson family; see
|
The vgQ.* functions are called internally by the gradient projection
optimization routines and would typically not be used directly. They can be
inspected using :::, for example:
GPArotation:::vgQ.oblimin. The gradient projection algorithms are
described in Bernaards and Jennrich (2005).
The T or Q suffix on rotation function names should be omitted
for the corresponding vgQ.* function. For example,
GPArotation:::vgQ.target is the criterion used by both
targetT and targetQ.
vgQ.oblimin | orthogonal or oblique | oblimin family |
vgQ.quartimin | oblique | oblimin with gam = 0 |
vgQ.target | orthogonal or oblique | target rotation |
vgQ.pst | orthogonal or oblique | partially specified target rotation |
vgQ.oblimax | oblique | maximizes overall kurtosis of loadings |
vgQ.entropy | orthogonal | minimum entropy |
vgQ.quartimax | orthogonal | maximizes variance of squared loadings within variables |
vgQ.varimax | orthogonal | maximizes variance of squared loadings within factors |
vgQ.simplimax | oblique | minimizes the k smallest squared loadings |
vgQ.bentler | orthogonal or oblique | Bentler invariant pattern simplicity |
vgQ.tandemI | orthogonal | Tandem principle I criterion |
vgQ.tandemII | orthogonal | Tandem principle II criterion |
vgQ.geomin | orthogonal or oblique | minimizes geometric mean of squared loadings |
vgQ.bigeomin | orthogonal or oblique | geomin with a general factor in column 1 |
vgQ.cf | orthogonal or oblique | Crawford-Ferguson family |
vgQ.infomax | orthogonal or oblique | infomax information criterion |
vgQ.mccammon | orthogonal | McCammon minimum entropy ratio |
vgQ.varimin | orthogonal | varimin criterion |
vgQ.bifactor | orthogonal or oblique | bifactor/biquartimin rotation |
vgQ.lp.wls | orthogonal or oblique | iterative reweighted least squares
for L^p rotation |
See rotations for details on rotation arguments.
New rotation criteria can be added by defining a function named
vgQ.newmethod. The function takes L as its first argument,
plus any additional arguments, and must return a list with elements
f, Gq, and Method.
Gradient projection without derivatives can be performed using the
GPArotateDF package; type
vignette("GPArotateDF", package = "GPArotation") at the command line.
A list with:
f |
The value of the rotation criterion at |
Gq |
The gradient of the criterion at |
Method |
A string indicating the criterion name. |
Coen A. Bernaards and Robert I. Jennrich with some R modifications by Paul Gilbert.
Bernaards, C.A. and Jennrich, R.I. (2005) Gradient Projection Algorithms and Software for Arbitrary Rotation Criteria in Factor Analysis. Educational and Psychological Measurement, 65, 676–696. doi: 10.1177/0013164404272507
rotations,
GPFRSorth
GPArotation:::vgQ.oblimin
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.